timespantools
=============

.. automodule:: abjad.tools.timespantools

.. only:: html

   Abstract classes
   ----------------

   .. autosummary::

      ~abjad.tools.timespantools.TimeRelation.TimeRelation

   Concrete classes
   ----------------

   .. autosummary::

      ~abjad.tools.timespantools.CompoundInequality.CompoundInequality
      ~abjad.tools.timespantools.OffsetTimespanTimeRelation.OffsetTimespanTimeRelation
      ~abjad.tools.timespantools.SimpleInequality.SimpleInequality
      ~abjad.tools.timespantools.Timespan.Timespan
      ~abjad.tools.timespantools.TimespanInventory.TimespanInventory
      ~abjad.tools.timespantools.TimespanTimespanTimeRelation.TimespanTimespanTimeRelation

   Functions
   ---------

   .. autosummary::

      ~abjad.tools.timespantools.offset_happens_after_timespan_starts.offset_happens_after_timespan_starts
      ~abjad.tools.timespantools.offset_happens_after_timespan_stops.offset_happens_after_timespan_stops
      ~abjad.tools.timespantools.offset_happens_before_timespan_starts.offset_happens_before_timespan_starts
      ~abjad.tools.timespantools.offset_happens_before_timespan_stops.offset_happens_before_timespan_stops
      ~abjad.tools.timespantools.offset_happens_during_timespan.offset_happens_during_timespan
      ~abjad.tools.timespantools.offset_happens_when_timespan_starts.offset_happens_when_timespan_starts
      ~abjad.tools.timespantools.offset_happens_when_timespan_stops.offset_happens_when_timespan_stops
      ~abjad.tools.timespantools.timespan_2_contains_timespan_1_improperly.timespan_2_contains_timespan_1_improperly
      ~abjad.tools.timespantools.timespan_2_curtails_timespan_1.timespan_2_curtails_timespan_1
      ~abjad.tools.timespantools.timespan_2_delays_timespan_1.timespan_2_delays_timespan_1
      ~abjad.tools.timespantools.timespan_2_happens_during_timespan_1.timespan_2_happens_during_timespan_1
      ~abjad.tools.timespantools.timespan_2_intersects_timespan_1.timespan_2_intersects_timespan_1
      ~abjad.tools.timespantools.timespan_2_is_congruent_to_timespan_1.timespan_2_is_congruent_to_timespan_1
      ~abjad.tools.timespantools.timespan_2_overlaps_all_of_timespan_1.timespan_2_overlaps_all_of_timespan_1
      ~abjad.tools.timespantools.timespan_2_overlaps_only_start_of_timespan_1.timespan_2_overlaps_only_start_of_timespan_1
      ~abjad.tools.timespantools.timespan_2_overlaps_only_stop_of_timespan_1.timespan_2_overlaps_only_stop_of_timespan_1
      ~abjad.tools.timespantools.timespan_2_overlaps_start_of_timespan_1.timespan_2_overlaps_start_of_timespan_1
      ~abjad.tools.timespantools.timespan_2_overlaps_stop_of_timespan_1.timespan_2_overlaps_stop_of_timespan_1
      ~abjad.tools.timespantools.timespan_2_starts_after_timespan_1_starts.timespan_2_starts_after_timespan_1_starts
      ~abjad.tools.timespantools.timespan_2_starts_after_timespan_1_stops.timespan_2_starts_after_timespan_1_stops
      ~abjad.tools.timespantools.timespan_2_starts_before_timespan_1_starts.timespan_2_starts_before_timespan_1_starts
      ~abjad.tools.timespantools.timespan_2_starts_before_timespan_1_stops.timespan_2_starts_before_timespan_1_stops
      ~abjad.tools.timespantools.timespan_2_starts_during_timespan_1.timespan_2_starts_during_timespan_1
      ~abjad.tools.timespantools.timespan_2_starts_when_timespan_1_starts.timespan_2_starts_when_timespan_1_starts
      ~abjad.tools.timespantools.timespan_2_starts_when_timespan_1_stops.timespan_2_starts_when_timespan_1_stops
      ~abjad.tools.timespantools.timespan_2_stops_after_timespan_1_starts.timespan_2_stops_after_timespan_1_starts
      ~abjad.tools.timespantools.timespan_2_stops_after_timespan_1_stops.timespan_2_stops_after_timespan_1_stops
      ~abjad.tools.timespantools.timespan_2_stops_before_timespan_1_starts.timespan_2_stops_before_timespan_1_starts
      ~abjad.tools.timespantools.timespan_2_stops_before_timespan_1_stops.timespan_2_stops_before_timespan_1_stops
      ~abjad.tools.timespantools.timespan_2_stops_during_timespan_1.timespan_2_stops_during_timespan_1
      ~abjad.tools.timespantools.timespan_2_stops_when_timespan_1_starts.timespan_2_stops_when_timespan_1_starts
      ~abjad.tools.timespantools.timespan_2_stops_when_timespan_1_stops.timespan_2_stops_when_timespan_1_stops
      ~abjad.tools.timespantools.timespan_2_trisects_timespan_1.timespan_2_trisects_timespan_1
